@@ -1,16 +1,18 @@
 #!/bin/bash
 
+GTEST_DIR=$SRC_DIR/googletest
+
 # Copy headers
-cp -r $SRC_DIR/include/gtest $PREFIX/include/
+cp -r $GTEST_DIR/include/gtest $PREFIX/include/
 
 # Build and copy static libraries
 mkdir build_static
 cd build_static
-cmake $SRC_DIR
+cmake $GTEST_DIR
 make
 cp libgtest.a $PREFIX/lib/
 cp libgtest_main.a $PREFIX/lib/
-cd $SRC_DIR
+cd $GTEST_DIR
 
 # Build and copy dynamic libraries
 UNAME="$(uname)"
@@ -24,7 +26,7 @@ fi
 
 mkdir build_dynamic
 cd build_dynamic
-cmake $SRC_DIR -Dgtest_build_tests=ON
+cmake $GTEST_DIR -Dgtest_build_tests=ON
 make
 cp libgtest_dll.$LIBEXT $PREFIX/lib/
-cd $SRC_DIR
+cd $GTEST_DIR
